aboutsummaryrefslogtreecommitdiffstats
path: root/modules
diff options
context:
space:
mode:
Diffstat (limited to 'modules')
-rw-r--r--modules/home.legacy/pkgs/default.nix3
1 files changed, 2 insertions, 1 deletions
diff --git a/modules/home.legacy/pkgs/default.nix b/modules/home.legacy/pkgs/default.nix
index 31942f0d..9cb360f4 100644
--- a/modules/home.legacy/pkgs/default.nix
+++ b/modules/home.legacy/pkgs/default.nix
@@ -85,7 +85,8 @@ with pkgs; let
SystemUpdate = [
fupdate # Generic update tool.
- update-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-flake # Nix flake update tool (meant to slot into `fupdate`).
];
FileListers = [